<c-vars size="default"></c-vars>
<a
    class="
    inline-flex items-center justify-center gap-2
    whitespace-nowrap rounded-md text-sm font-medium
    ring-offset-background transition-colors focus-visible:outline-none
    focus-visible:ring-2 focus-visible:ring-ring focus-visible:ring-offset-2
    disabled:pointer-events-none disabled:opacity-50 [&_svg]:pointer-events-none
    [&_svg]:size-4 [&_svg]:shrink-0
    text-primary underline-offset-4 hover:underline

    {% if size == 'default' %}h-9 px-4 py-2
    {% elif size == 'sm' %}h-8 rounded-md px-3 text-xs
    {% elif size == 'lg' %}h-10 rounded-md px-8
    {% elif size == 'icon' %}h-9 w-9{% endif %}

    {% if class %}
    {{ class }}
    {% endif %}
    "
    {{ attrs }}
>
    {{ slot }}
</a>
